#####################################################
## Compute target moments - 5 periods model
## Authors: Blasutto Fabio and David de la Croix
####################################################

# set the directory to where the files are located
setwd(paste(dire,"\\big base", sep = ""))

#load database 
dico <- as.data.frame(read_excel("Dictionary.xlsx"))
basew  <- as.data.frame(read_excel("Profs-wiki-all.xlsx"))
membersa  <- as.data.frame(read_excel("Italian academies.xlsx"))
membersu  <- as.data.frame(read_excel("Italian universities.xlsx"))

if (unio){members<-membersu}else{members<-rbind(membersa,membersu)}

setwd(diroutput)

#removing people without worldcat
members <- members[members$Worldcat!="NA",]

#remove if field of research is 9 ()
members <- members[members$Field!="9" ,] 


#removing people not yet checked
members <- members[members$Forbidden!=8888,]
members <- members[members$Forbidden!=7777,]
members$PKey<-members$Persons_PKey



#


#Sample
substrRight <- function(x, n){
  substr(x, nchar(x)-n+1, nchar(x))
}

members$nation<-substrRight(members$BirthPlace,3)
if(weak){members<-members[members$WeakLink=="FALSE",]}
if(ita+itas+itan){members<-members[members$nation=="ITA",]}

#members<-members[members$nation=="ITA",]

#remove duplicates
members  <- members[!duplicated(members$Persons_PKey), ]
basew  <- basew[!duplicated(basew), ]



plist<-unique(members$Persons_PKey)


plist2<-plist
#Find the performance in the base generated by the wiki routine

# take the index of quality
members$perfl <- 0
members$bypub <- 0
members$pubp <- 0
members$pubb <- 0
basew$public<- basew$public


#basew.pca <- prcomp(basew[,3:12], center = TRUE,scale. = TRUE)
for (j in plist){
  

  members[members$Persons_PKey==j,"perfl"] <- log(max(c(dico[dico$PKey==j,"publi_by"],1)))  # for individual quality
  
  
  if(notonlyby){
    members[members$Persons_PKey==j,"perfl"] <- log(max(c(dico[dico$PKey==j,"publications"],1)))
  }
  if(wiki){
    members[members$Persons_PKey==j,"perfl"] <- log(max(c(dico[dico$PKey==j,"LengthWikiN"],1)))
  }
  members[members$Persons_PKey==j,"pubb"] <- (c(dico[dico$PKey==j,"publications"]))
  members[members$Persons_PKey==j,"bypub"] <- (c(dico[dico$PKey==j,"publi_by"]))
  members[members$Persons_PKey==j,"pubp"] <- (c(dico[dico$PKey==j,"publi_about"]))
  members[members$Persons_PKey==j,"lat"] <- (c(basew[basew$PKey==j,"Locations_Latitude"]))[1]
}


nbase <- nrow(members)
for (i in (1:nbase)){
  members[i,"refdatel"] <- basew[basew$PKey==members[i,"PKey"],"refdatel"]
}
#North south of italy
if(itan){members<-members[members$lat>=43.8,]}
if(itas){members<-members[members$lat< 43.8,]}


members<-members[!is.na(members$perfl),]

if(!notonlyby){members<-members[members$bypub>0,]}
#if(wiki){members<-members[members$perfl>4.094345,]}

#we remove this guy who started in Spain and ended in Italy after 1750
#members <- members[members$PKey!="Pou-B-1727",]

#Get Nationality
members$nation<-substring(members$BirthPlace,nchar(members$BirthPlace)-2,nchar(members$BirthPlace))


members  <- members[members$refdatel>=1400,]
members  <- members[members$refdatel<1751,]


source(paste(dirinput,"\\graph-smoothed.R", sep = "")) 

################################################
# PART 2: COMPUTE THE MOMENTS
################################################

#We consider 5 periods here
members  <- members[members$refdatel>=1400,]
members  <- members[members$refdatel<1750,]



threshold0<- 1400
threshold1 <- 1470
threshold2 <- 1540
threshold3 <- 1610
threshold4<-1680
threshold5<-1750

members  <- members[members$refdatel>=threshold0,]
members  <- members[!members$refdatel>threshold5,]

members1 <- members[members$refdatel<threshold1,]
members2 <- members[threshold2>members$refdatel & members$refdatel>=threshold1,]
members3 <- members[threshold3>members$refdatel & members$refdatel>=threshold2,]
members4 <- members[threshold4>members$refdatel & members$refdatel>=threshold3,]
members5 <- members[members$refdatel>=threshold4,]


memberscensored1 <- members[members$Forbidden<9999 & members$refdatel<threshold1,]
membersnotcensored1 <- members[members$Forbidden==9999 & members$refdatel<threshold1,]

memberscensored2 <- members[members$Forbidden<9999 & 
                              threshold2>members$refdatel & members$refdatel>=threshold1,]
membersnotcensored2 <- members[members$Forbidden==9999 &
                                 threshold2>members$refdatel & members$refdatel>=threshold1,]

memberscensored3 <- members[members$Forbidden<9999 &
                              threshold3>members$refdatel & members$refdatel>=threshold2,]
membersnotcensored3 <- members[members$Forbidden==9999 &
                                 threshold3>members$refdatel & members$refdatel>=threshold2,]

memberscensored4 <- members[members$Forbidden<9999 &
                              threshold4>members$refdatel & members$refdatel>=threshold3,]
membersnotcensored4 <- members[members$Forbidden==9999  &
                                 threshold4>members$refdatel & members$refdatel>=threshold3,]


memberscensored5 <- members[members$Forbidden<9999 & members$refdatel>=threshold4,]
membersnotcensored5 <- members[members$Forbidden==9999 & members$refdatel>=threshold4,]

memberscensored<-members[members$Forbidden<9999,]
membersnotcensored<-members[members$Forbidden>=9999,]




cenq<-c(mean(memberscensored1$perf),
        mean(memberscensored2$perfl),
        mean(memberscensored3$perfl),
        mean(memberscensored4$perfl),
        mean(memberscensored5$perfl))

ncenq<-c(mean(membersnotcensored1$perf),
         mean(membersnotcensored2$perfl),
         mean(membersnotcensored3$perfl),
         mean(membersnotcensored4$perfl),
         mean(membersnotcensored5$perfl))

q<-c(mean(members1$perf),
     mean(members2$perfl),
     mean(members3$perfl),
     mean(members4$perfl),
     mean(members5$perfl))

mcenq<-c(median(memberscensored1$perf),
         median(memberscensored2$perfl),
         median(memberscensored3$perfl),
         median(memberscensored4$perfl),
         median(memberscensored5$perfl))

mncenq<-c(median(membersnotcensored1$perf),
          median(membersnotcensored2$perfl),
          median(membersnotcensored3$perfl),
          median(membersnotcensored4$perfl),
          median(membersnotcensored5$perfl))

mq<-c(median(members1$perf),
      median(members2$perfl),
      median(members3$perfl),
      median(members4$perfl),
      median(members5$perfl))



maxperf<-round(max(members$perfl)+0.5,)
maxpeople<-100/2

maxperfd <- 2* maxperf

bv<-(0:maxperfd)
bv<-bv/2


# get the k_t,K^theta_R and m_t*beta_t in the data
Embeta<-numeric(length=5)
Eqr<-numeric(length=5)
ENC<-numeric(length=5)
Eqc<-numeric(length=5)
Eq<-numeric(length=5)
Em<-numeric(length=5)
EqrQ75<-numeric(length=5)
ENCQ75<-numeric(length=5)
EqQ75<-numeric(length=5)
EqrM<-numeric(length=5)
ENCM<-numeric(length=5)
EqM<-numeric(length=5)


for (i in 1:5) {
  
  nam <- paste("members", i, sep = "")
  namc <- paste("memberscensored", i, sep = "")
  namnc <- paste("membersnotcensored", i, sep = "")
  
  #compute means
  Embeta[i]<-length(get(namc)$perfl)/(length(get(namc)$perfl)+ length(get(namnc)$perfl))
  Eqr[i]=mean(get(namc)$perfl)
  ENC[i]=mean(get(namnc)$perfl)
  Eq[i]=mean(get(nam)$perfl)
  
  #compute medians
  EqrM[i]=median(get(namc)$perfl)
  ENCM[i]=median(get(namnc)$perfl)
  EqM[i]=median(get(nam)$perfl)
  
  #compute 75 percentile
  EqrQ75[i]=quantile(get(namc)$perfl,0.75)
  ENCQ75[i]=quantile(get(namnc)$perfl,0.75)
  EqQ75[i]=quantile(get(nam)$perfl,0.75)
  
  
  
}
rm(nam,namc,namnc)


sink(paste0(diroutput,"\\momentstofit.Rnw"))

cat(paste('\\begin{table}[htbp]
  	\\centering
  \\begin{tabularx}{\\textwidth}{ l *{5}{Y}}
  \\hline
  \\hline
  Moment description& \\multicolumn{5}{c}{Period}\\\\
     & 1400-70 &1470-1540 & 1540-1610 & 1610-80 & 1680-1750 \\\\\\cline{1-6}\\rule{-4pt}{2.5ex}
     Number of authors
      &  ',round(nrow(members1), digits=2),'      &  ',round(nrow(members2), digits=2),'       &  ',round(nrow(members3), digits=2),'      &  ',round(nrow(members4), digits=2),'     &  ',round(nrow(members5), digits=2),'  \\\\
     \\% censored scholars
      & ',round(Embeta[1], digits=2),'    & ',round(Embeta[2], digits=2),'     & ',round(Embeta[3], digits=2),'    & ',round(Embeta[4], digits=2),'   & ',round(Embeta[5], digits=2),' \\\\ 
  \\rule{-4pt}{2.5ex}
    Log publications per scholar, median
      & ',round(EqM[1], digits=2),'    & ',round(EqM[2], digits=2),'     & ',round(EqM[3], digits=2),'    & ',round(EqM[4], digits=2),'   & ',round(EqM[5], digits=2),' \\\\    
  \\rule{-4pt}{2.5ex}
  Log publications per scholar, $75^{th}$ percentile
      & ',round(EqQ75[1], digits=2),'    & ',round(EqQ75[2], digits=2),'     & ',round(EqQ75[3], digits=2),'    & ',round(EqQ75[4], digits=2),'   & ',round(EqQ75[5], digits=2),' \\\\    
  \\rule{-4pt}{2.5ex}
  Log publications per (censored) scholar, median 
      & ',round(EqrM[1], digits=2),'    & ',round(EqrM[2], digits=2),'     & ',round(EqrM[3], digits=2),'    & ',round(EqrM[4], digits=2),'   & ',round(EqrM[5], digits=2),' \\\\    
  \\rule{-4pt}{2.5ex}
  Log publications per (censored) scholar, $75^{th}$ percentile
      & ',round(EqrQ75[1], digits=2),'    & ',round(EqrQ75[2], digits=2),'     & ',round(EqrQ75[3], digits=2),'    & ',round(EqrQ75[4], digits=2),'   & ',round(EqrQ75[5], digits=2),' \\\\    
  \\hline
  \\hline
  \\end{tabularx}
  	{\\raggedright Note: periods: 1:1400-70, 2:1470-1540, 3:1540-1610, 4:1610-80, 5:1680-1750 \\par}
  \\caption{Moments to fit}\\label{table:momentstofit}
  \\end{table}'))

sink()
Sweave("momentstofit.Rnw")

# get the variance of uality in the first period to get theta
Evar<-var(members1$perfl)

##################################
# get bootstraped CI for graph
##################################
ns<-length(members$perfl)
boots<-numeric(ns)
Bmbeta<-array(,c(5,nboots))
Bq<-array(,c(5,nboots))
BNC<-array(,c(5,nboots))
Bqr<-array(,c(5,nboots))
BqM<-array(,c(5,nboots))
BNCM<-array(,c(5,nboots))
BqrM<-array(,c(5,nboots))
Bq75<-array(,c(5,nboots))
BNC75<-array(,c(5,nboots))
Bqr75<-array(,c(5,nboots))

#aa<-replicate(nboots, sample(members, ns,replace=TRUE))
if (!(itas+itan)){
for(i in 1:nboots){
  
  
  boots<-as.data.frame(sample(members$Persons_PKey,ns,replace=TRUE))
  memb<-merge(boots,members,
              by.x='sample(members$Persons_PKey, ns, replace = TRUE)',
              by.y='Persons_PKey')
  
  # compute what we need
  #memb<-members[boots%in% members$Persons_PKey]
  #memb<-subset(members,members$Persons_PKey==boots)
  
  #We consider 4 periods here
  members1 <- memb[memb$refdatel<threshold1,]
  members2 <- memb[threshold2>memb$refdatel & memb$refdatel>=threshold1,]
  members3 <- memb[threshold3>memb$refdatel & memb$refdatel>=threshold2,]
  members4 <- memb[threshold4>memb$refdatel & memb$refdatel>=threshold3,]
  members5 <- memb[memb$refdatel>=threshold4,]
  
  memberscensored1 <- memb[memb$Forbidden<9999 & memb$refdatel<threshold1,]
  membersnotcensored1 <- memb[memb$Forbidden==9999 & memb$refdatel<threshold1,]
  
  memberscensored2 <- memb[memb$Forbidden<9999 & 
                             threshold2>memb$refdatel & memb$refdatel>=threshold1,]
  membersnotcensored2 <- memb[memb$Forbidden==9999 &
                                threshold2>memb$refdatel & memb$refdatel>=threshold1,]
  
  memberscensored3 <- memb[memb$Forbidden<9999 &
                             threshold3>memb$refdatel & memb$refdatel>=threshold2,]
  membersnotcensored3 <- memb[memb$Forbidden==9999 &
                                threshold3>memb$refdatel & memb$refdatel>=threshold2,]
  
  memberscensored4 <- memb[memb$Forbidden<9999 &
                             threshold4>memb$refdatel & memb$refdatel>=threshold3,]
  membersnotcensored4 <- memb[memb$Forbidden==9999  &
                                threshold4>memb$refdatel & memb$refdatel>=threshold3,]
  
  memberscensored5 <- memb[memb$Forbidden<9999 & memb$refdatel>=threshold4,]
  membersnotcensored5 <- memb[memb$Forbidden==9999 & memb$refdatel>=threshold4,]
  
  
  memberscensored <- memb[memb$Forbidden<9999 ,]
  
  
  #the moments now
  for(j in 1:5){
    
    nam <- paste("members", j, sep = "")
    namc <- paste("memberscensored", j, sep = "")
    namnc <- paste("membersnotcensored", j, sep = "")
    
    Bmbeta[j,i]<-length(get(namc)$perfl)/(length(get(namc)$perfl)+ length(get(namnc)$perfl))
    Bqr[j,i]=mean(get(namc)$perfl)
    Bq[j,i]=mean(get(nam)$perfl)
    BNC[j,i]=mean(get(namnc)$perfl)
    BqrM[j,i]=median(get(namc)$perfl)
    BqM[j,i]=median(get(nam)$perfl)
    BNCM[j,i]=median(get(namnc)$perfl)
    Bqr75[j,i]=quantile(get(namc)$perfl,0.75)
    Bq75[j,i]=quantile(get(nam)$perfl,0.75)
    BNC75[j,i]=quantile(get(namnc)$perfl,0.75)
    
  }}}

#get finally the CI
CImbeta<-array(,c(2,5))
CIq<-array(,c(2,5))
CIqr<-array(,c(2,5))
CINC<-array(,c(2,5))
CImbeta75<-array(,c(2,5))
CIq75<-array(,c(2,5))
CIqr75<-array(,c(2,5))
CINC75<-array(,c(2,5))

if (!(itas+itan)){
for(j in 1:5){
  CImbeta[,j]<-quantile(Bmbeta[j,],c(0.025,0.975))
  CIq[,j]<-quantile(BqM[j,],c(0.025,0.975))
  CIqr[,j]<-quantile(BqrM[j,],c(0.025,0.975))
  CINC[,j]<-quantile(BNCM[j,],c(0.025,0.975))
  CIq75[,j]<-quantile(Bq75[j,],c(0.025,0.975))
  CIqr75[,j]<-quantile(Bqr75[j,],c(0.025,0.975))
  CINC75[,j]<-quantile(BNC75[j,],c(0.025,0.975))
  
}}

#Save and store the results
Bqc<-BNC
Bm<-Bmbeta
momentss<-list("Embeta"=Embeta,"Eqr"=Eqr,
               "ENC"=ENC,"Eqc"=Eqc,
               "Em"=Em,"EqrQ75"=EqrQ75,
               "ENCQ75"=ENCQ75,"EqQ75"=EqQ75,
               "EqrM"=EqrM,"ENCM"=ENCM,
               "Bmbeta"=Bmbeta,"Bqr"=Bqr,
               "BNC"=BNC,"Bqc"=Bqc,
               "Bm"=Bm,"Bqr75"=Bqr75,
               "BNC75"=BNC75,"Bq75"=Bq75,
               "BqrM"=BqrM,"BNCM"=BNCM,
               "EqM"=EqM,"CImbeta"=CImbeta,
               "CIq"=CIq,"CIqr"=CIqr,
               "CINC"=CINC,"CIq75"=CIq75,
               "CIqr75"=CIqr75,"CINC75"=CINC75,
               "Eq"=Eq,
               "GAs"="none")



list.save(momentss, paste0(diroutput,'\\data.Rdata'))  

#For reply to Editor, point 4: significance in difference of quality censored/not censored
#quantile(Bqr[1,]-BNC[1,],c(0.025,0.975))
#quantile(Bqr[5,]-BNC[5,],c(0.025,0.975))
